@@ -22,6 +22,7 @@ from otcextensions.common import exc
 
 from otcextensions.sdk.cloud import rds as _rds
 from otcextensions.sdk.cloud import cce as _cce
+from otcextensions.sdk.cloud import dds as _dds
 
 
 _logger = _log.setup_logging('openstack')
@@ -83,6 +84,7 @@ OTC_SERVICES = {
     'dds': {
         'service_type': 'dds',
         'endpoint_service_type': 'ddsv3',
+        'append_project_id': True
     },
     'deh': {
         'service_type': 'deh',
@@ -343,6 +345,7 @@ def load(conn, **kwargs):
 
     extend_instance(conn, _rds.RdsMixin)
     extend_instance(conn, _cce.CceMixin)
+    extend_instance(conn, _dds.DdsMixin)
 
     return None
 
